==> fwbuilder_1.0.0.orig.tar.gz: fwbuilder-1.0.0.orig/src/gui/DiscoveryDruidP05Dialog.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2001 Vadim Kurland

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: DiscoveryDruidP05Dialog.cc,v 1.7 2001/12/18 22:48:29 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#include "config.h"
#include "fwbuilder/libfwbuilder-config.h"
#include "DiscoveryDruidP05Dialog.hh"

using namespace libfwbuilder;


DiscoveryDruidP05Dialog::DiscoveryDruidP05Dialog()
{

    p05_txt->set_line_wrap(true);

    ((Gtk::Label*)(hosts_file->get_child()))->set_alignment(0.0,0.5);
    ((Gtk::Label*)(dns->get_child()))->set_alignment(0.0,0.5);
    ((Gtk::Label*)(network_discovery->get_child()))->set_alignment(0.0,0.5);
    ((Gtk::Label*)(scan_subnet->get_child()))->set_alignment(0.0,0.5);

#ifndef HAVE_LIBSNMP

    ((Gtk::Label*)(network_discovery->get_child()))->set_text("Perform network discovery using SNMP\n(Feature disabled because program is compiled with no SNMP support)"  );
    ((Gtk::Label*)(network_discovery->get_child()))->set_justify(GTK_JUSTIFY_LEFT);
    network_discovery->set_sensitive(false);

#endif

}

==> fwbuilder_1.1.2.orig.tar.gz: fwbuilder-1.1.2/src/gui/DiscoveryDruidP05Dialog.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2001 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: DiscoveryDruidP05Dialog.cc,v 1.13 2003/03/02 08:12:43 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#include "config.h"
#include "fwbuilder/libfwbuilder-config.h"
#include "DiscoveryDruidP05Dialog.hh"

using namespace libfwbuilder;


DiscoveryDruidP05Dialog::DiscoveryDruidP05Dialog()
{

    p05_txt->set_line_wrap(true);

    ((Gtk::Label*)(hosts_file->get_child()))->set_alignment(0.0,0.5);

    ((Gtk::Label*)(dns->get_child()))->set_alignment(0.0,0.5);
    ((Gtk::Label*)(network_discovery->get_child()))->set_alignment(0.0,0.5);
    ((Gtk::Label*)(scan_subnet->get_child()))->set_alignment(0.0,0.5);

#ifndef HAVE_GOODLIBRESOLV
    ((Gtk::Label*)(dns->get_child()))->set_text(_("Import DNS zone\n(Feature disabled because the program has been compiled without advanced DNS library.)") );
    ((Gtk::Label*)(dns->get_child()))->set_justify(GTK_JUSTIFY_LEFT);
    dns->set_sensitive(false);
#endif

#ifdef __MINGW32__
    ((Gtk::Label*)(dns->get_child()))->set_text(_("Import DNS zone\n(Feature disabled because FWBuilder doesn't support asynchronous dns zone transfers on Win32.)") );
    ((Gtk::Label*)(dns->get_child()))->set_justify(GTK_JUSTIFY_LEFT);
    dns->set_sensitive(false);
#endif

#ifndef HAVE_LIBSNMP
    ((Gtk::Label*)(network_discovery->get_child()))->set_text(_("Perform network discovery using SNMP\n(Feature disabled because program has been compiled without SNMP support)")  );
    ((Gtk::Label*)(network_discovery->get_child()))->set_justify(GTK_JUSTIFY_LEFT);
    network_discovery->set_sensitive(false);
#endif

}
